@@ -6,15 +6,17 @@ cvGrace <- function(X, Y, L, lambda.L, lambda.1, lambda.2, K = 10){
   lambda.1 <- unique(sort(lambda.1, decreasing = TRUE))
   lambda.L <- unique(sort(lambda.L, decreasing = TRUE))
   lambda.2 <- unique(sort(lambda.2, decreasing = TRUE))
-  noL1 <- ifelse(lambda.1 == 0, TRUE, FALSE)
-
-  if(length(lambda.1) == 1){
+  
+  oneL1 <- (length(lambda.1) == 1)
+  noL1 <- oneL1 & (sum(lambda.1 == 0) == 1)
+  
+  if(oneL1){
     lambda.1 <- c(lambda.1 + 0.01, lambda.1)
   }
   p <- ncol(X)
   n <- nrow(X)
   lam1 <- matrix(nrow = length(lambda.L), ncol = length(lambda.2))
-  ERR <- matrix(0, nrow = length(lambda.L), ncol = length(lambda.2))
+  ERR <- matrix(NA, nrow = length(lambda.L), ncol = length(lambda.2))
   for(iL in 1:length(lambda.L)){
     lL <- lambda.L[iL]
     for(i2 in 1:length(lambda.2)){
@@ -22,15 +24,18 @@ cvGrace <- function(X, Y, L, lambda.L, lambda.1, lambda.2, K = 10){
       Lnew <- lL * L + l2 * diag(p)
       eL <- eigen(Lnew)
       S <- eL$vectors %*% sqrt(diag(eL$values))
-      l2star <- 1
       l1star <- lambda.1
-      Xstar <- rbind(X, sqrt(l2star) * t(S)) / sqrt(1 + l2star)
+      Xstar <- rbind(X, t(S)) / sqrt(2)
       Ystar <- c(Y, rep(0, p))
-      gammastar <- l1star / sqrt(1 + l2star) / 2 / (n + p)
+      gammastar <- l1star / sqrt(2) / 2 / (n + p)
       cvres <- cv.glmnet(Xstar, Ystar, lambda = gammastar, intercept = FALSE, standardize = FALSE, nfolds = K)
       lam1[iL, i2] <- which.min(abs(gammastar - cvres$lambda.min))
-      if(noL1){
-        ERR[iL, i2] <- cvres$cvm[2]
+      if(oneL1){
+        if(length(cvres$cvm) == 1){
+          ERR[iL, i2] <- cvres$cvm[1]
+        }else{
+          ERR[iL, i2] <- cvres$cvm[2]
+        }
       }else{
         ERR[iL, i2] <- cvres$cvm[lam1[iL, i2]]
       }
@@ -39,6 +44,8 @@ cvGrace <- function(X, Y, L, lambda.L, lambda.1, lambda.2, K = 10){
   idx <- which(ERR == min(ERR), arr.ind = TRUE)
   if(noL1){
     resl1 <- 0
+  }else if(oneL1){
+    resl1 <- lambda.1[2]  
   }else{
     resl1 <- lambda.1[lam1[idx]][1]
   }
